==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeHttpGetFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReadinessProbeHttpGetFluentImpl<A extends ReadinessProbeHttpGetFluent<A>> extends BaseFluent<A> implements ReadinessProbeHttpGetFluent<A>{
  public ReadinessProbeHttpGetFluentImpl() {
  }
  public ReadinessProbeHttpGetFluentImpl(ReadinessProbeHttpGet instance) {
    this.withHttpGet(instance.getHttpGet()); 
  }
  private HTTPHealthCheckConfigBuilder httpGet;
  
  /**
   * This method has been deprecated, please use method buildHttpGet instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPHealthCheckConfig getHttpGet() {
    return this.httpGet!=null ?this.httpGet.build():null;
  }
  public HTTPHealthCheckConfig buildHttpGet() {
    return this.httpGet!=null ?this.httpGet.build():null;
  }
  public A withHttpGet(HTTPHealthCheckConfig httpGet) {
    _visitables.get("httpGet").remove(this.httpGet);
    if (httpGet!=null){ this.httpGet= new HTTPHealthCheckConfigBuilder(httpGet); _visitables.get("httpGet").add(this.httpGet);} else { this.httpGet = null; _visitables.get("httpGet").remove(this.httpGet); } return (A) this;
  }
  public Boolean hasHttpGet() {
    return this.httpGet != null;
  }
  public ReadinessProbeHttpGetFluent.HttpGetNested<A> withNewHttpGet() {
    return new ReadinessProbeHttpGetFluentImpl.HttpGetNestedImpl();
  }
  public ReadinessProbeHttpGetFluent.HttpGetNested<A> withNewHttpGetLike(HTTPHealthCheckConfig item) {
    return new ReadinessProbeHttpGetFluentImpl.HttpGetNestedImpl(item);
  }
  public ReadinessProbeHttpGetFluent.HttpGetNested<A> editHttpGet() {
    return withNewHttpGetLike(getHttpGet());
  }
  public ReadinessProbeHttpGetFluent.HttpGetNested<A> editOrNewHttpGet() {
    return withNewHttpGetLike(getHttpGet() != null ? getHttpGet(): new HTTPHealthCheckConfigBuilder().build());
  }
  public ReadinessProbeHttpGetFluent.HttpGetNested<A> editOrNewHttpGetLike(HTTPHealthCheckConfig item) {
    return withNewHttpGetLike(getHttpGet() != null ? getHttpGet(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ReadinessProbeHttpGetFluentImpl that = (ReadinessProbeHttpGetFluentImpl) o;
    if (httpGet != null ? !httpGet.equals(that.httpGet) :that.httpGet != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpGet,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpGet != null) { sb.append("httpGet:"); sb.append(httpGet); }
    sb.append("}");
    return sb.toString();
  }
  class HttpGetNestedImpl<N> extends HTTPHealthCheckConfigFluentImpl<ReadinessProbeHttpGetFluent.HttpGetNested<N>> implements ReadinessProbeHttpGetFluent.HttpGetNested<N>,Nested<N>{
    HttpGetNestedImpl(HTTPHealthCheckConfig item) {
      this.builder = new HTTPHealthCheckConfigBuilder(this, item);
    }
    HttpGetNestedImpl() {
      this.builder = new HTTPHealthCheckConfigBuilder(this);
    }
    HTTPHealthCheckConfigBuilder builder;
    public N and() {
      return (N) ReadinessProbeHttpGetFluentImpl.this.withHttpGet(builder.build());
    }
    public N endHttpGet() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeHttpGetFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReadinessProbeHttpGetFluentImpl<A extends ReadinessProbeHttpGetFluent<A>> extends BaseFluent<A> implements ReadinessProbeHttpGetFluent<A>{
  public ReadinessProbeHttpGetFluentImpl() {
  }
  public ReadinessProbeHttpGetFluentImpl(ReadinessProbeHttpGet instance) {
    if (instance != null) {
      this.withHttpGet(instance.getHttpGet());
    }
  }
  private HTTPHealthCheckConfigBuilder httpGet;
  
  /**
   * This method has been deprecated, please use method buildHttpGet instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPHealthCheckConfig getHttpGet() {
    return this.httpGet!=null ?this.httpGet.build():null;
  }
  public HTTPHealthCheckConfig buildHttpGet() {
    return this.httpGet!=null ?this.httpGet.build():null;
  }
  public A withHttpGet(HTTPHealthCheckConfig httpGet) {
    _visitables.get("httpGet").remove(this.httpGet);
    if (httpGet!=null){ this.httpGet= new HTTPHealthCheckConfigBuilder(httpGet); _visitables.get("httpGet").add(this.httpGet);} else { this.httpGet = null; _visitables.get("httpGet").remove(this.httpGet); } return (A) this;
  }
  public Boolean hasHttpGet() {
    return this.httpGet != null;
  }
  public ReadinessProbeHttpGetFluentImpl.HttpGetNested<A> withNewHttpGet() {
    return new ReadinessProbeHttpGetFluentImpl.HttpGetNestedImpl();
  }
  public ReadinessProbeHttpGetFluentImpl.HttpGetNested<A> withNewHttpGetLike(HTTPHealthCheckConfig item) {
    return new ReadinessProbeHttpGetFluentImpl.HttpGetNestedImpl(item);
  }
  public ReadinessProbeHttpGetFluentImpl.HttpGetNested<A> editHttpGet() {
    return withNewHttpGetLike(getHttpGet());
  }
  public ReadinessProbeHttpGetFluentImpl.HttpGetNested<A> editOrNewHttpGet() {
    return withNewHttpGetLike(getHttpGet() != null ? getHttpGet(): new HTTPHealthCheckConfigBuilder().build());
  }
  public ReadinessProbeHttpGetFluentImpl.HttpGetNested<A> editOrNewHttpGetLike(HTTPHealthCheckConfig item) {
    return withNewHttpGetLike(getHttpGet() != null ? getHttpGet(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReadinessProbeHttpGetFluentImpl that = (ReadinessProbeHttpGetFluentImpl) o;
    if (!java.util.Objects.equals(httpGet, that.httpGet)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpGet,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpGet != null) { sb.append("httpGet:"); sb.append(httpGet); }
    sb.append("}");
    return sb.toString();
  }
  class HttpGetNestedImpl<N> extends HTTPHealthCheckConfigFluentImpl<ReadinessProbeHttpGetFluentImpl.HttpGetNested<N>> implements ReadinessProbeHttpGetFluentImpl.HttpGetNested<N>,Nested<N>{
    HttpGetNestedImpl(HTTPHealthCheckConfig item) {
      this.builder = new HTTPHealthCheckConfigBuilder(this, item);
    }
    HttpGetNestedImpl() {
      this.builder = new HTTPHealthCheckConfigBuilder(this);
    }
    HTTPHealthCheckConfigBuilder builder;
    public N and() {
      return (N) ReadinessProbeHttpGetFluentImpl.this.withHttpGet(builder.build());
    }
    public N endHttpGet() {
      return and();
    }
    
  }
  
}
